﻿using C1.Win.C1Chart;
using System;
using System.Drawing;
using System.Linq;
using System.Windows.Forms;

namespace C1ChartApplication
{
    public partial class Form1 : Form
    {
        string _dstt = "";
        Point _pt = new Point();
        string DataSeriesTooltipText
        {
            get { return _dstt; }
            set
            {
                if (_dstt != value)
                {
                    _dstt = value;

                    // Set tooltip for all series
                    foreach (ChartDataSeries ds in c1Chart1.ChartGroups[0].ChartData.SeriesList)
                        ds.TooltipText = _dstt;
                }
            }
        }

        public Form1()
        {
            InitializeComponent();
        }

        private void c1Chart1_ShowTooltip(object sender, C1.Win.C1Chart.ShowTooltipEventArgs e)
        {
            
            if (sender is ChartDataSeries)
            {
                // Create new tooltip text
                if (c1Chart1.ToolTip.PlotElement == PlotElementEnum.Series)
                {
                    ChartDataSeries ds = (ChartDataSeries)sender;

                    Point p = Control.MousePosition;
                    p = c1Chart1.PointToClient(p);
                    //c1Chart1.I
                    //c1Chart1.ChartGroups[0].ChartData.SeriesList[0].PointData.

                    double x = 0, y = 0;

                    // Callculate data coordinates
                    if (ds.Group.CoordToDataCoord(p.X, p.Y, ref x, ref y))
                        e.TooltipText = string.Format("{0}\nx = {1:#.##}\ny = {2:#.##}", ds.Label, x, y);
                    else
                        e.TooltipText = "";
                }
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //create data for the chart
            double[] xdata = { 0, 10, 20, 30, 40, 50, 60, 70 };
            double[] ydata = { 0, 0.5, 0.5, 1, 1 , 0.5, 0.5, 0 };

            //clear previous series
            c1Chart1.ChartGroups[0].ChartData.SeriesList.Clear();

            //add one series to the chart
            C1.Win.C1Chart.ChartDataSeries ds = c1Chart1.ChartGroups[0].ChartData.SeriesList.AddNewSeries();

            //copy the x and y data
            ds.X.CopyDataIn(xdata);
            ds.Y.CopyDataIn(ydata);

            //set the chart type
            c1Chart1.ChartGroups[0].ChartType = C1.Win.C1Chart.Chart2DTypeEnum.XYPlot;

            //create new font for the X and Y axes
            Font f = new Font("Arial", 10, FontStyle.Bold);
            c1Chart1.ChartArea.Style.ForeColor = Color.DarkGray;
            c1Chart1.ChartArea.AxisX.Font = f;
            c1Chart1.ChartArea.AxisX.Text = "Time";
            c1Chart1.ChartArea.AxisX.GridMajor.Visible = true;
            c1Chart1.ChartArea.AxisX.GridMajor.Color = Color.LightGray;
            c1Chart1.ChartArea.AxisY.Font = f;
            c1Chart1.ChartArea.AxisY.Text = "HTC";
            c1Chart1.ChartArea.AxisY.GridMajor.Visible = true;
            c1Chart1.ChartArea.AxisY.GridMajor.Color = Color.LightGray;

            //modify line style appearance
            ds.LineStyle.Color = Color.LightPink;
            ds.LineStyle.Pattern = LinePatternEnum.Solid;
            ds.LineStyle.Thickness = 1;

            //modify the symbol style appearance
            ds.SymbolStyle.Shape = SymbolShapeEnum.Box;
            ds.SymbolStyle.Color = Color.LightPink;
            ds.SymbolStyle.OutlineColor = Color.Black;
            ds.SymbolStyle.Size = 5;
            ds.SymbolStyle.OutlineWidth = 1;
            c1Chart1.ChartArea.PlotArea.BackColor = Color.White;
            
            c1Chart1.ToolTip.PlotElement = PlotElementEnum.Series;
            c1Chart1.ToolTip.Enabled = true;
            DataSeriesTooltipText = "Series: {#TEXT}\r\nx = {#XVAL}\r\ny = {#YVAL}";
            c1Chart1.MouseDown += C1Chart1_MouseDown;
        }

        private void C1Chart1_MouseDown(object sender, MouseEventArgs e)
        {
            if(e.Button == MouseButtons.Left)
            {
                _pt = Control.MousePosition;
            }
        }

        private void addBtn_Click(object sender, EventArgs e)
        {
            var currentSeries = c1Chart1.ChartGroups[0].ChartData.SeriesList[0];
            var pt = c1Chart1.PointToClient(_pt);
            if (currentSeries != null && currentSeries.PointData.Length > 0)
            {
                double x = 0, y = 0;
                if (currentSeries.Group.CoordToDataCoord(pt.X, pt.Y, ref x, ref y))
                {
                    var DataSeriesX = (currentSeries.X.CopyDataOut() as double[]).ToList();
                    var DataSeriesY = (currentSeries.Y.CopyDataOut() as double[]).ToList();

                    int seriesIndex = 0, pointIndex = 0, distance = 0;
                    currentSeries.Group.CoordToDataIndex(pt.X, pt.Y, CoordinateFocusEnum.XCoord, ref seriesIndex, ref pointIndex, ref distance);

                    if (DataSeriesX[pointIndex] < x) pointIndex++;
                    DataSeriesX.Insert(pointIndex, x);
                    DataSeriesY.Insert(pointIndex, y);

                    currentSeries.X.CopyDataIn(DataSeriesX.ToArray());
                    currentSeries.Y.CopyDataIn(DataSeriesY.ToArray());
                }
                c1Chart1.Update();
            }
        }

        private void deleteBtn_Click(object sender, EventArgs e)
        {
            var pt = c1Chart1.PointToClient(_pt);
            int pntInd = 0, dist = 0;
            var currentSeries = c1Chart1.ChartGroups[0].ChartData.SeriesList[0];
            if (currentSeries != null)
            {
                if(currentSeries.PointData.Length > 0)
                {
                    if(currentSeries.Group.CoordToPointIndex(pt.X, pt.Y, PlotElementEnum.Points, 0, ref pntInd, ref dist))
                    {
                        if(dist < 10)
                        {
                            currentSeries.PointData.RemoveAt(pntInd);
                        }
                    }
                    c1Chart1.Update();
                }
            }
        }

        private void saveBtn_Click(object sender, EventArgs e)
        {
            try
            {
                c1Chart1.SaveImage("../../ChartImage.png", System.Drawing.Imaging.ImageFormat.Png);
                MessageBox.Show("Image saved successfully");
            }
            catch 
            {
                MessageBox.Show("Image save failed!");
            }
        }
    }
}
